using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.SettingsProvider;
using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.UIControls;

public partial class SiteManager_Sites_Site_Edit_General : SiteManagerPage
{
    protected int siteId = 0;
    protected string siteName = "";
    protected string currentCulture = "";

    protected void Page_Load(object sender, EventArgs e)
    {
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        RequiredFieldValidatorCodeName.ErrorMessage = ResHelper.GetString("Administration-Site_Edit.RequiresCodeName");
        RequiredFieldValidatorDisplayName.ErrorMessage = ResHelper.GetString("Administration-Site_Edit.RequiresDisplayName");
        RequiredFieldValidatorDomainName.ErrorMessage = ResHelper.GetString("Administration-Site_Edit.RequiresDomainName");

        lblCodeName.Text = ResHelper.GetString("Site_Edit.CodeName");
        lblDescription.Text = ResHelper.GetString("Site_Edit.Description");
        lblDisplayName.Text = ResHelper.GetString("Site_Edit.DisplayName");
        lblDomainName.Text = ResHelper.GetString("Site_Edit.DomainName");
        lblCulture.Text = ResHelper.GetString("Site_Edit.ContentCulture");
        //lblLicenseKey.Text = ResHelper.GetString("Site_Edit.LicenseKey");
        lblCssStyle.Text = ResHelper.GetString("NewSite_SiteDetails.CssStyle");
        lblEditorStyle.Text = ResHelper.GetString("Site_Edit.EditorStyleSheet");
        lblVisitorCulture.Text = ResHelper.GetString("Site_Edit.VisitorCulture");
        ButtonOk.Text = ResHelper.GetString("general.ok");
        btnChange.Text = ResHelper.GetString("general.change");

        ltlScript.Text = ScriptHelper.GetScript("var pageChangeUrl='" + ResolveUrl("~/CMSSiteManager/Sites/CultureChange.aspx") + "'; function ChangeCulture(){" + Page.ClientScript.GetPostBackEventReference(this.btnHidden, "") + "  } ");

        siteId = ValidationHelper.GetInteger(Request.QueryString["siteid"], 0);

        if ((siteId > 0) && (!RequestHelper.IsPostBack()))
        {
            SiteInfo currentSiteInfo = SiteInfoProvider.GetSiteInfo(siteId);
            if ((currentSiteInfo != null) && (currentSiteInfo.SiteName != null))
            {
                siteName = currentSiteInfo.SiteName;

                // fill dropdown lists with ccs style sheets
                FillCssStylesheetDrops(siteName);

                TextBoxCodeName.Text = siteName;
                TextBoxDescription.Text = currentSiteInfo.Description;
                TextBoxDisplayName.Text = currentSiteInfo.DisplayName;
                TextBoxDomainName.Text = currentSiteInfo.DomainName;

                SetSelectedItem(drpCssStyle, currentSiteInfo.SiteDefaultStylesheetID.ToString());
                SetSelectedItem(drpEditorStyle, currentSiteInfo.SiteDefaultEditorStylesheet.ToString());

                if (CultureHelper.GetDefaultCulture(siteName) != null)
                {
                    CultureInfo ci = CultureInfoProvider.GetCultureInfo(CultureHelper.GetDefaultCulture(siteName));

                    if (ci != null)
                    {
                        lblCultureValue.Text = ci.CultureName;
                        currentCulture = ci.CultureCode;
                    }
                }

                // Load visitor content culture
                LoadCultureData(siteName);

                // 

                // Set actual content culture
                if ((currentSiteInfo.DefaultVisitorCulture != null) && (currentSiteInfo.DefaultVisitorCulture != ""))
                {
                    SetSelectedItem(drpVisitorCulture, currentSiteInfo.DefaultVisitorCulture);
                }
            }
        }

        btnChange.OnClientClick = "OpenCultureChanger('" + siteId.ToString() + "','" + currentCulture + "'); return false;";
    }


    void SetSelectedItem(DropDownList drp, string value)
    {
        drp.ClearSelection();
        for (int i = 0; i < drp.Items.Count; i++)
        {
            if (drp.Items[i].Value == value)
            {
                drp.Items[i].Selected = true;
                break;
            }
        }
    }


    protected void LoadCultureData(string siteName)
    {
        DataSet mDs = new DataSet();
        mDs = CultureInfoProvider.GetSiteCultures(siteName);

        if (mDs != null)
        {
            drpVisitorCulture.DataSource = mDs;
            drpVisitorCulture.DataTextField = mDs.Tables[0].Columns["CultureName"].ColumnName.ToString();
            drpVisitorCulture.DataValueField = mDs.Tables[0].Columns["CultureCode"].ColumnName.ToString();

            drpVisitorCulture.DataBind();
        }

        drpVisitorCulture.Items.Insert(0, ResHelper.GetString("Site_Edit.Automatic"));
        drpVisitorCulture.Items[0].Value = "";
    }


    /// <summary>
    /// Save current site's data.
    /// </summary>
    protected void ButtonOk_Click(object sender, EventArgs e)
    {
        // Finds whether required fields are not empty
        string result = new Validator().NotEmpty(TextBoxDisplayName.Text, ResHelper.GetString("Administration-Site_Edit.RequiresDisplayName")).NotEmpty(TextBoxCodeName.Text, ResHelper.GetString("Administration-Site_Edit.RequiresCodeName")).NotEmpty(TextBoxDomainName.Text, ResHelper.GetString("Administration-Site_Edit.RequiresDomainName")).IsCodeName(TextBoxCodeName.Text, ResHelper.GetString("Administration-Site_Edit.NotValidCodeName")).Result;

        if (result == "")
        {
            SiteInfo si = null;
            // Finds whether edited site code name is unique
            si = SiteInfoProvider.GetSiteInfo(TextBoxCodeName.Text.Trim());

            if ((si == null) || (si.SiteID == siteId))
            {
                if (si == null)
                {
                    // Get siteinfo by primary key
                    si = SiteInfoProvider.GetSiteInfo(siteId);
                }
                // Update SiteInfo
                if (SaveSite(si))
                {
                    // Display save information
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Administration-Site_Edit.SiteExists");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }


    /// <summary>
    /// Save edited site.
    /// </summary>
    private bool SaveSite(SiteInfo oldSi)
    {
        // Correct domain name and return it to textbox
        //TextBoxDomainName.Text = CorrectDomainName(TextBoxDomainName.Text);

        // Get SiteInfo with the given siteID
        SiteInfo currentSiteInfo = oldSi.Clone();
        if (siteId > 0)
        {
            try
            {
                bool runSite = (currentSiteInfo.Status == SiteStatusEnum.Running);
                SiteInfoProvider.StopSite(currentSiteInfo.SiteName);

                // Clear settings if sitename changes
                if (currentSiteInfo.SiteName.ToLower() != TextBoxCodeName.Text.Trim().ToLower())
                {
                    SettingsKeyProvider.Clear();
                }

                // Reindex hashtable with sessions if SiteName changes
                if (oldSi.SiteName != TextBoxCodeName.Text)
                {
                    SessionManager.ReindexSessionsInfosHashtable(oldSi.SiteName, TextBoxCodeName.Text);
                }

                // Update SiteInfo parameters
                currentSiteInfo.SiteName = TextBoxCodeName.Text;
                currentSiteInfo.Description = TextBoxDescription.Text;
                currentSiteInfo.DisplayName = TextBoxDisplayName.Text;
                currentSiteInfo.DomainName = TextBoxDomainName.Text;
                currentSiteInfo.DefaultVisitorCulture = drpVisitorCulture.SelectedItem.Value;
                currentSiteInfo.SiteID = siteId;
                currentSiteInfo.SiteDefaultStylesheetID = ValidationHelper.GetInteger(drpCssStyle.SelectedItem.Value, 0);
                currentSiteInfo.SiteDefaultEditorStylesheet = ValidationHelper.GetInteger(drpEditorStyle.SelectedItem.Value, 0);
                currentSiteInfo.Status = SiteStatusEnum.Stopped;

                // Save SiteInfo
                SiteInfoProvider.SetSiteInfo(currentSiteInfo);

                if (runSite)
                {
                    // Run current site
                    SiteInfoProvider.RunSite(currentSiteInfo.SiteName);
                }
            }
            catch (RunningSiteException exc)
            {
                lblError.Visible = true;
                lblError.Text = exc.Message;
            }
            return true;
        }
        else
        {
            return false;
        }
    }


    /// <summary>
    /// Removes white characters from the beginning and end. Also removes protocol declarations and 'www.' string from begin.
    /// </summary>
    /// <param name="domainName">String to correct</param>
    /// <returns>Corrected string</returns>
    protected string CorrectDomainName(string domainName)
    {
        string result = domainName;
        result = result.Trim();
        string lowcaseResult = result.ToLower();

        while (lowcaseResult.IndexOf("https://") > -1)
        {
            result = result.Remove(lowcaseResult.IndexOf("https://"), 8);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("https://"), 8);
        }

        while (lowcaseResult.IndexOf("http://") > -1)
        {
            result = result.Remove(lowcaseResult.IndexOf("http://"), 7);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("http://"), 7);
        }

        while (lowcaseResult.StartsWith("www.", true, null))
        {
            result = result.Remove(lowcaseResult.IndexOf("www."), 4);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("www."), 4);
        }

        return result;
    }


    /// <summary>
    /// Fills dropdownlist with css stylesheets for specified site.
    /// </summary>
    /// <param name="siteName">Site name.</param>
    protected void FillCssStylesheetDrops(string siteName)
    {
        DataSet ds = null;

        // Fill drop down list for site stylesheets
        ds = CssStylesheetInfoProvider.GetCssStylesheets(siteName);

        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            ds.Tables[0].DefaultView.Sort = "StylesheetDisplayName ASC";
            drpCssStyle.DataTextField = "StylesheetDisplayName";
            drpCssStyle.DataValueField = "StylesheetID";
            drpCssStyle.DataSource = ds.Tables[0].DefaultView;
            drpCssStyle.DataBind();
        }

        // fill drop down list for editor stylesheets
        ds = CssStylesheetInfoProvider.GetAllCssStylesheets();
        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            ds.Tables[0].DefaultView.Sort = "StylesheetDisplayName ASC";
            drpEditorStyle.DataTextField = "StylesheetDisplayName";
            drpEditorStyle.DataValueField = "StylesheetID";
            drpEditorStyle.DataSource = ds.Tables[0].DefaultView;
            drpEditorStyle.DataBind();
        }

        // add default item to the Editor CSS stylesheet drop down list
        ListItem item = new ListItem();
        item.Text = ResHelper.GetString("Administration-Site_Edit.SiteStyleSheet");
        item.Value = "0";
        drpEditorStyle.Items.Insert(0, item);

        // add default item to the CssStylesheet drop down list
        item = new ListItem();
        item.Text = ResHelper.GetString("general.selectnone");
        item.Value = "0";
        drpCssStyle.Items.Insert(0, item);
    }


    /// <summary>
    /// On default culture change
    /// </summary>
    protected void btnHidden_Click(object sender, EventArgs e)
    {
        SiteInfo si = SiteInfoProvider.GetSiteInfo(siteId);

        if (si != null)
        {
            if (CultureHelper.GetDefaultCulture(si.SiteName) != null)
            {
                CultureInfo ci = CultureInfoProvider.GetCultureInfo(CultureHelper.GetDefaultCulture(si.SiteName));
                if (ci != null)
                {
                    lblCultureValue.Text = ci.CultureName;
                    btnChange.OnClientClick = "OpenCultureChanger('" + siteId.ToString() + "','" + ci.CultureCode + "'); return false;";
                }
            }
        }
    }
}

