using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Xml;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.Controls;
using CMS.PortalEngine;

public partial class CMSWebParts_Text_editableimage : CMSAbstractEditableWebPart
{
    #region "Controls"

    /// <summary>
    /// Image
    /// </summary>
    protected Image imgImage = null;

    /// <summary>
    /// Region title
    /// </summary>
    protected Label lblTitle = null;

    /// <summary>
    /// Error label
    /// </summary>
    protected Label lblError = null;

    /// <summary>
    /// Region panel
    /// </summary>
    protected Panel pnlEditor = null;

    /// <summary>
    /// Image selector
    /// </summary>
    protected ImageSelector selPath = null;

    /// <summary>
    /// Image title
    /// </summary>
    protected string mImageTitle = null;

    #endregion


    #region "Public properties"

    /// <summary>
    /// Gets or sets the title of the image region which is displayed in the EDIT mode
    /// </summary>
    public string ImageTitle
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("ImageTitle"), this.ID);
        }
        set
        {
            this.SetValue("ImageTitle", value);
        }
    }


    /// <summary>
    /// Gets or sets the image width
    /// </summary>
    public int ImageWidth
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("ImageWidth"), 0);
        }
        set
        {
            this.SetValue("ImageWidth", value);
        }
    }


    /// <summary>
    /// Gets or sets the image height
    /// </summary>
    public int ImageHeight
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("ImageHeight"), 0);
        }
        set
        {
            this.SetValue("ImageHeight", value);
        }
    }


    /// <summary>
    /// Gets or sets the alternative image text (ALT tag of the image)
    /// </summary>
    public string AlternateText
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("AlternateText"), "");
        }
        set
        {
            this.SetValue("AlternateText", value);
        }
    }


    /// <summary>
    /// Gets or sets the value that indicates whether the path to file is displayed in EDIT mode
    /// </summary>
    public bool DisplaySelectorTextBox
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("DisplaySelectorTextBox"), this.selPath.ImagePathTextBox.Visible);
        }
        set
        {
            this.SetValue("DisplaySelectorTextBox", value);
        }
    }


    /// <summary>
    /// Gets or sets the name of the css class applied to the image.
    /// </summary>
    public string ImageCssClass
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("ImageCssClass"), "");
        }
        set
        {
            this.SetValue("ImageCssClass", value);
        }
    }


    /// <summary>
    /// Gets or sets the style tag of the image
    /// </summary>
    public string ImageStyle
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("ImageStyle"), "");
        }
        set
        {
            this.SetValue("ImageStyle", value);
        }
    }


    /// <summary>
    /// Gets or sets the value that indicates whether the permissions are checked
    /// </summary>
    public bool CheckPermissions
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("CheckPermissions"), false);
        }
        set
        {
            this.SetValue("CheckPermissions", value);
        }
    }

    #endregion


    /// <summary>
    /// Constructor
    /// </summary>
    public CMSWebParts_Text_editableimage()
    {
        this.PreRender += new EventHandler(Page_PreRender);
        this.Load += new EventHandler(Page_Load);
    }


    /// <summary>
    /// Overriden CreateChildControls method
    /// </summary>
    protected override void CreateChildControls()
    {
        this.Controls.Clear();
        base.CreateChildControls();

        if (!this.StopProcessing)
        {
            // Create controls by actual page mode
            switch (this.PageManager.ViewMode)
            {
                case ViewModeEnum.Edit:
                case ViewModeEnum.EditDisabled:
                    // Main editor panel
                    this.pnlEditor = new Panel();
                    this.pnlEditor.ID = "pnlEditor";
                    this.pnlEditor.CssClass = "EditableImageEdit EditableImage_" + this.ID;
                    if (this.ImageWidth > 0)
                    {
                        this.pnlEditor.Style.Add(HtmlTextWriterStyle.Width, this.ImageWidth.ToString() + "px;");
                        //this.pnlEditor.Width = new Unit(this.DialogWidth); // Causes Invalid cast on Render
                    }
                    this.Controls.Add(pnlEditor);

                    // Title label
                    this.lblTitle = new Label();
                    this.lblTitle.EnableViewState = false;
                    this.lblTitle.CssClass = "EditableTextTitle";
                    this.pnlEditor.Controls.Add(this.lblTitle);

                    // Error label
                    this.lblError = new Label();
                    this.lblError.EnableViewState = false;
                    this.lblError.CssClass = "EditableTextError";
                    this.pnlEditor.Controls.Add(this.lblError);

                    // Add image selector
                    this.selPath = new ImageSelector(null, true);
                    this.selPath.Culture = CMSContext.CurrentUser.PreferredUICultureCode;
                    this.selPath.EnableOpenInFull = false;
                    this.selPath.ID = "selPath";
                    this.selPath.UseImagePath = true;
                    this.selPath.ImageCssClass = this.ImageCssClass;
                    this.selPath.ImageStyle = this.ImageStyle;
                    this.selPath.ShowTextBox = this.DisplaySelectorTextBox;
                    this.pnlEditor.Controls.Add(this.selPath);

                    this.selPath.Enabled = (this.PageManager.ViewMode == ViewModeEnum.Edit);
                    this.selPath.IsLiveSite = (this.PageManager.ViewMode == ViewModeEnum.LiveSite);
                    break;

                default:
                    // Display content in non editing modes
                    this.imgImage = new Image();
                    this.imgImage.ID = "imgImage";
                    if (this.ImageCssClass != "")
                    {
                        this.imgImage.CssClass = this.ImageCssClass;
                    }
                    if (this.ImageStyle != "")
                    {
                        this.imgImage.Attributes.Add("style", this.ImageStyle);
                    }
                    this.imgImage.AlternateText = this.AlternateText;
                    this.imgImage.ToolTip = this.AlternateText;
                    this.imgImage.EnableViewState = false;
                    this.Controls.Add(this.imgImage);
                    break;
            }
        }
    }


    /// <summary>
    /// Load the content to the region, applies the InheritContent
    /// </summary>
    /// <param name="pageInfo">PageInfo with the content data</param>
    /// <param name="forceReload">If true, the content is forced to reload</param>
    public override void LoadContent(PageInfo pageInfo, bool forceReload)
    {
        if (pageInfo == null)
        {
            return;
        }

        // Get the content
        PageInfo sourceInfo = pageInfo;
        string content = ValidationHelper.GetString(pageInfo.EditableWebParts[this.ID.ToLower()], "");

        // Load the content if published
        if ((CMSContext.ViewMode != ViewModeEnum.LiveSite) || !this.SelectOnlyPublished || ((sourceInfo != null) && sourceInfo.IsPublished))
        {
            LoadContent(content, forceReload);
        }
    }


    /// <summary>
    /// Loads the control content
    /// </summary>
    /// <param name="content">Content to load</param>
    /// <param name="forceReload">If true, the content is forced to reload</param>
    public override void LoadContent(string content, bool forceReload)
    {
        if (!this.StopProcessing)
        {
            // Load the properties
            this.EnsureChildControls();

            string path = null;
            // Load the image data
            if (!string.IsNullOrEmpty(content))
            {
                XmlDocument xml = new XmlDocument();
                xml.LoadXml(content);

                XmlNodeList properties = xml.SelectNodes("image/property");
                if (properties != null)
                {
                    foreach (XmlNode node in properties)
                    {
                        if (node.Attributes["name"] != null)
                        {
                            switch (node.Attributes["name"].Value.ToLower())
                            {
                                case "imagepath":
                                    path = ResolveUrl(node.InnerText.Trim());
                                    break;
                            }
                        }
                    }
                }
            }

            switch (this.PageManager.ViewMode)
            {
                case ViewModeEnum.Edit:
                case ViewModeEnum.EditDisabled:
                    if (this.ImageWidth > 0)
                    {
                        selPath.ImageWidth = this.ImageWidth;
                    }
                    if (this.ImageHeight > 0)
                    {
                        selPath.ImageHeight = this.ImageHeight;
                    }
                    if (!RequestHelper.IsPostBack())
                    {
                        this.selPath.Value = path;
                    }

                    if (this.ImageTitle != "")
                    {
                        this.lblTitle.Text = this.ImageTitle;
                    }
                    else
                    {
                        this.lblTitle.Visible = false;
                    }

                    break;

                default:
                    if (string.IsNullOrEmpty(path))
                    {
                        this.Visible = false;
                        return;
                    }

                    if (this.ImageWidth > 0)
                    {
                        path = UrlHelper.AddParameterToUrl(path, "width", this.ImageWidth.ToString());
                    }
                    if (this.ImageHeight > 0)
                    {
                        path = UrlHelper.AddParameterToUrl(path, "height", this.ImageHeight.ToString());
                    }
                    imgImage.AlternateText = this.AlternateText;

                    // Check authorization
                    bool isAuthorized = true;
                    if (this.CheckPermissions)
                    {
                        isAuthorized = this.PageManager.IsAuthorized;
                    }

                    // Only published
                    if ((CMSContext.ViewMode != ViewModeEnum.LiveSite) || !this.SelectOnlyPublished || (this.PagePlaceholder.PageInfo.IsPublished))
                    {
                        if (isAuthorized)
                        {
                            imgImage.ImageUrl = path;
                        }
                        else
                        {
                            imgImage.Visible = false;
                        }
                    }
                    else
                    {
                        imgImage.Visible = false;
                    }

                    break;
            }
        }
    }


    /// <summary>
    /// Gets the current control content
    /// </summary>
    public override string GetContent()
    {
        if (!this.StopProcessing)
        {
            this.EnsureChildControls();

            switch (this.PageManager.ViewMode)
            {
                case ViewModeEnum.Edit:
                case ViewModeEnum.EditDisabled:
                    string path = UrlHelper.UnResolveUrl(this.selPath.Value.Trim(), Request.ApplicationPath);
                    if (!string.IsNullOrEmpty(path))
                    {
                        XmlDocument xml = new XmlDocument();
                        xml.LoadXml("<image></image>");

                        // Add path
                        XmlNode newNode = xml.CreateElement("property");

                        XmlAttribute attr = xml.CreateAttribute("name");
                        attr.Value = "imagepath";
                        newNode.Attributes.Append(attr);


                        newNode.InnerText = path;
                        if (xml.DocumentElement != null)
                        {
                            xml.DocumentElement.AppendChild(newNode);
                        }
                        return xml.OuterXml;
                    }
                    else
                    {
                        return string.Empty;
                    }
            }
        }

        return null;
    }


    /// <summary>
    /// Load event handler
    /// </summary>
    void Page_Load(object sender, EventArgs e)
    {
    }


    /// <summary>
    /// PreRender event handler
    /// </summary>
    void Page_PreRender(object sender, EventArgs e)
    {
        if (!this.StopProcessing)
        {
            switch (this.PageManager.ViewMode)
            {
                case ViewModeEnum.Edit:
                case ViewModeEnum.EditDisabled:
                    // Set enabled
                    if (this.selPath != null)
                    {
                        this.selPath.Enabled = (this.PageManager.ViewMode == ViewModeEnum.Edit);
                    }

                    if (this.lblError != null)
                    {
                        this.lblError.Visible = (this.lblError.Text != "");
                    }
                    this.lblTitle.Text = this.ImageTitle;
                    break;
            }
        }
    }
}
